[][src]Module range_ext::intersect

Enums

Intersection

Intersection of two ranges from point of the first range

IntersectionExt

More precise intersection of two ranges from point of the first range

Traits

Intersect