[][src]Enum range_ext::intersect::IntersectionExt

pub enum IntersectionExt {
    Bellow,
    BellowOverlap,
    Within,
    Same,
    Over,
    AboveOverlap,
    Above,
}

More precise intersection of two ranges from point of the first range

Variants

Bellow

The self is below the other

BellowOverlap

The self is below but overlaping

Within

The self is within the other

Same

The self is same as the other

Over

The self is over the other, the other is within the self

AboveOverlap

The self is above but overlaping

Above

The self is above the other

Methods

impl IntersectionExt[src]

pub fn intersection(&self) -> Intersection[src]

Get simpler intersection

pub fn is_any(&self) -> bool[src]

Test if there is any intersection