[−][src]Enum range_ext::intersect::IntersectionExt
More precise intersection of two ranges from point of the first range
Variants
BellowThe self is below the other
BellowOverlapThe self is below but overlaping
WithinThe self is within the other
SameThe self is same as the other
OverThe self is over the other, the other is within the self
AboveOverlapThe self is above but overlaping
AboveThe self is above the other
Methods
impl IntersectionExt[src]
pub fn intersection(&self) -> Intersection[src]
Get simpler intersection
pub fn is_any(&self) -> bool[src]
Test if there is any intersection